Go Metrics API
===============

An API for querying `vumi-go`_ metrics.

.. _vumi-go: http://github.com/praekelt/vumi-go

|gometrics-ci|_ |gometrics-cover|_

.. |gometrics-ci| image:: https://travis-ci.org/praekelt/go-metrics-api.png?branch=develop
.. _gometrics-ci: https://travis-ci.org/praekelt/go-metrics-api

.. |gometrics-cover| image:: https://coveralls.io/repos/praekelt/go-metrics-api/badge.png?branch=develop
.. _gometrics-cover: https://coveralls.io/r/praekelt/go-metrics-api

You can contact the Vumi development team in the following ways:

* via *email* by joining the the `vumi-dev@googlegroups.com`_ mailing list
* on *irc* in *#vumi* on the `Freenode IRC network`_

.. _vumi-dev@googlegroups.com: https://groups.google.com/forum/?fromgroups#!forum/vumi-dev
.. _Freenode IRC network: https://webchat.freenode.net/?channels=#vumi

Issues can be filed in the GitHub issue tracker. Please don't use the issue
tracker for general support queries.
